@@ -53,7 +53,7 @@ G_BEGIN_DECLS
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:STRING,STRING,STRING (/usr/src/ports/totem-pl-parser/totem-pl-parser-3.10.5-1.i686/src/totem-pl-parser-3.10.5/plparse/totemplparser-marshal.list:1) */
+/* VOID:STRING,STRING,STRING (/usr/src/ports/totem-pl-parser/totem-pl-parser-3.10.7-1.x86_64/src/totem-pl-parser-3.10.7/plparse/totemplparser-marshal.list:1) */
 G_GNUC_INTERNAL void _totemplparser_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                                         GValue       *return_value,
                                                                         guint         n_param_values,
@@ -73,9 +73,9 @@ _totemplparser_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                            gpointer     arg_2,
                                                            gpointer     arg_3,
                                                            gpointer     data2);
-  register GMarshalFunc_VOID__STRING_STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_STRING_STRING callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 4);
 
@@ -98,7 +98,7 @@ _totemplparser_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,BOXED (/usr/src/ports/totem-pl-parser/totem-pl-parser-3.10.5-1.i686/src/totem-pl-parser-3.10.5/plparse/totemplparser-marshal.list:2) */
+/* VOID:STRING,BOXED (/usr/src/ports/totem-pl-parser/totem-pl-parser-3.10.7-1.x86_64/src/totem-pl-parser-3.10.7/plparse/totemplparser-marshal.list:2) */
 G_GNUC_INTERNAL void _totemplparser_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -117,9 +117,9 @@ _totemplparser_marshal_VOID__STRING_BOXED (GClosure     *closure,
                                                    gpointer     arg_1,
                                                    gpointer     arg_2,
                                                    gpointer     data2);
-  register GMarshalFunc_VOID__STRING_BOXED callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  GMarshalFunc_VOID__STRING_BOXED callback;
+  GCClosure *cc = (GCClosure*) closure;
+  gpointer data1, data2;
 
   g_return_if_fail (n_param_values == 3);
 
